@@ -225,7 +225,7 @@ repo_info = \
         },
         "check_connection":{
             "args":[],
-            "ret":["bool", True, None, None, False, True]
+            "ret":["bool", False, None, None, False, True]
         },
         "create_config_maps":{
             "args":[["cluster_name", False, "Name"], ["config_map_user_settings", True, "ConfigMapUserSetting", None, True]]
